import React, { useState } from 'react';
import { Button } from "strapi-helper-plugin";
import { saveAs } from "file-saver";
import { fetchEntries } from "../../utils/contentApis";
import { HFlex, ModelItem } from "./ui-components";
import JsonDataDisplay from "../../components/JsonDataDisplay";
import * as FileSaver from 'file-saver';
import * as XLSX from 'xlsx';

const ExportModel = ({ model }) => {
  const [fetching, setFetching] = useState(false);
  const [content, setContent] = useState(null);
  const fetchModelData = () => {
    setFetching(true);
    fetchEntries(model.apiID, model.schema.kind).then((data) => {
      setContent(data);
    }).finally(() => {
      setFetching(false);
    });
  };

  const downloadXl = () => {
    const current = new Date();
    const fileType = 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet;charset=UTF-8';
    const fileExtension = '.xlsx';
    content.forEach(record => {
      Object.keys(record).forEach(columnName => {
        if (typeof record[columnName] === 'object' && record[columnName] !== null) {
          if ("id" in record[columnName]) {
            record[columnName] = record[columnName].id
          }
        }
      });

    });
    const ws = XLSX.utils.json_to_sheet(content);
    const wb = { Sheets: { 'data': ws }, SheetNames: ['data'] };
    const excelBuffer = XLSX.write(wb, { bookType: 'xlsx', type: 'array' });
    const data = new Blob([excelBuffer], { type: fileType });
    FileSaver.saveAs(data, `${model.apiID}-${current.getTime()}` + fileExtension);

  };

  const downloadJson = () => {
    const current = new Date();
    const file = new File([JSON.stringify(content)],
      `${model.apiID}-${current.getTime()}.json`,
      { type: "application/json;charset=utf-8" });
    saveAs(file);
  };
  return (<ModelItem>
    <HFlex>
      <span className='title'>{model.schema.name}</span>
      <div>
        <Button disabled={fetching}
          loader={fetching}
          onClick={fetchModelData}
          secondaryHotline>{fetching ? "Fetching" : "Fetch"}</Button>
        <Button disabled={!content}
          onClick={downloadXl}
          kind={content ? 'secondaryHotline' : 'secondary'}
        >Export</Button>
      </div>
    </HFlex>
    {
      content && (<JsonDataDisplay data={content} />)
    }
  </ModelItem>)
};

export default ExportModel;
